@@ -10,13 +10,14 @@ use Module::Find;
 use Class::Load;
 
 our $AUTHORITY = 'cpan:MAROS';
-our $VERSION = "2.08";
+our $VERSION = "2.09";
 
 use 5.008000;
 
 our $DEFAULT_ALGORITHM = 'Phonix';
 our @PREDICATES_CHECKED;
-our @AVAILABLE_ALGORITHMS = grep { s/^Text::Phonetic::(.+)$/$1/x } 
+our @AVAILABLE_ALGORITHMS = grep
+    { s/^Text::Phonetic::(.+)$/$1/x }
     findsubmod Text::Phonetic;
 
 has 'unidecode' => (
@@ -26,13 +27,11 @@ has 'unidecode' => (
     documentation   => q[Transliterate strings to ASCII before processing]
 );
 
-after 'BUILDARGS' => sub { 
+after 'BUILDARGS' => sub {
     my ($class) = @_;
     return $class->check_predicates;
 };
 
-__PACKAGE__->meta->make_immutable;
-
 # ----------------------------------------------------------------------------
 # Class methods
 
@@ -49,7 +48,7 @@ sub register_algorithm {
 
 sub check_predicates {
     my ($class) = @_;
-    
+
     if ($class->can('_predicates')
         && ! grep { $class eq $_ } @PREDICATES_CHECKED) {
         my @predicates = $class->_predicates;
@@ -71,23 +70,23 @@ sub check_predicates {
 sub load {
     my $self = shift;
     my $params = (scalar @_ == 1 && ref($_[0]) eq 'HASH') ? shift : { @_ };
-    
+
     my $algorithm = delete($params->{algorithm}) || $DEFAULT_ALGORITHM;
     my $class = __PACKAGE__.'::'.$algorithm;
-    
+
     unless (grep { $algorithm eq $_ } @AVAILABLE_ALGORITHMS) {
         croak("Could not load '$algorithm' phonetic algorithm: Algorithm not available");
     }
-    
+
     unless (Class::Load::is_class_loaded($class)) {
         my ($ok,$error) = Class::Load::try_load_class($class);
         unless ($ok) {
             croak("Could not load '$algorithm' phonetic algorithm: $error")
         }
     }
-    
+
     $class->check_predicates;
-    
+
     return $class->new($params);
 }
 
@@ -96,13 +95,13 @@ sub load {
 
 sub encode {
     my $self = shift;
-    
+
     # Single value
     if (scalar(@_) == 1) {
         my $string = shift;
-        $string = Text::Unidecode::unidecode($string) 
+        $string = Text::Unidecode::unidecode($string)
             if ($self->unidecode);
-        return 
+        return
             unless defined $string && $string !~ /^\s*$/;
         return $self->_do_encode($string);
     # Expand list
@@ -130,22 +129,22 @@ sub compare {
     if ($self->unidecode) {
         $string1 = Text::Unidecode::unidecode($string1);
         $string2 = Text::Unidecode::unidecode($string2);
-        
+
         # Also not very likely, but has to be checked
         return 99 if ($string1 eq $string2);
     }
-    
+
     my $value1 = $self->_do_encode($string1);
     my $value2 = $self->_do_encode($string2);
-    
+
     return 0 unless (defined $value1 && defined $value2);
-    
+
     return $self->_do_compare($self->_do_encode($string1),$self->_do_encode($string2));
 }
-    
+
 sub _do_compare {
     my ($self,$result1,$result2) = @_;
-    
+
     return 50 if ($result1 eq $result2);
     return 0;
 }
@@ -161,7 +160,7 @@ sub _is_inlist {
     my $string = shift;
     return 0 unless defined $string;
     my $list = (scalar @_ == 1 && ref($_[0]) eq 'ARRAY') ? shift : \@_;
-     
+
     return 1 if grep {$string eq $_ } @$list;
     return 0;
 }
@@ -175,11 +174,11 @@ sub _compare_list {
         next unless defined $element1;
         foreach my $element2 (@$list2) {
             next unless defined $element2;
-            return 1 
+            return 1
                 if $element1 eq $element2;
         }
-    } 
-    
+    }
+
     return 0;
 }
 
@@ -196,11 +195,11 @@ Text::Phonetic - A base class for phonetic algorithms
 =head1 SYNOPSIS
 
   use Text::Phonetic::Metaphone;
-  
+
   my $phonetic = Text::Phonetic::Metaphone->new();
   $encoded_string = $phonetic->encode($string);
   @encoded_list = $phonetic->encode(@list);
-  
+
   my $same = $phonetic->compare($string1,$string2);
 
 Or
@@ -209,12 +208,12 @@ Or
   my $phonetic = Text::Phonetic->load( algorithm => 'Phonix' );
   $encoded_string = $phonetic->encode($string);
 
-This module provides an easy and convinient way to encode names with various 
+This module provides an easy and convinient way to encode names with various
 phonetic algorithms. It acts as a wrapper around other phonetic algorithm
 modules like L<Text::Metaphone>, L<Text::DoubleMetaphone>, L<Text::Soundex>
-and also implements some other algorithms such as 
+and also implements some other algorithms such as
 L<Text::Phonetic::DaitchMokotoff>, L<Text::Phonetic::Koeln>,
-L<Text::Phonetic::Phonem> and L<Text::Phonetic::Phonix>. 
+L<Text::Phonetic::Phonem> and L<Text::Phonetic::Phonix>.
 
 This module can easily be subclassed.
 
@@ -225,10 +224,10 @@ This module can easily be subclassed.
 =head3 new
 
  $obj = Text::Phonetic::SUBCLASS->new(%PARAMETERS)
- 
-You can pass arbitrary attributes to the constructor. The only global 
-attribute is C<unidecode> which defaults to 1 if not set. This attribute 
-controls if non-latin characters should be transliterated to A-Z 
+
+You can pass arbitrary attributes to the constructor. The only global
+attribute is C<unidecode> which defaults to 1 if not set. This attribute
+controls if non-latin characters should be transliterated to A-Z
 (see also L<Text::Unidecode>).
 
 Additional attributes may be defined by the various implementation classes.
@@ -248,7 +247,7 @@ Alternative constructor which also loads the requested algorithm subclass.
  @RETURN_LIST = $obj->encode(@LIST);
  OR
  $RETURN_LIST_REF = $obj->encode(@LIST);
- 
+
 Encodes the given string or list of strings. Returns a single value, array or
 array reference depending on the caller context and parameters.
 
@@ -257,18 +256,18 @@ Returns undef on an empty/undefined/whitespace only string.
 =head3 compare
 
  $RETURN_CODE = $obj->compare($STRING1,$STRING2);
- 
+
 The return code is an integer between 100 and 0 indicating the likelihood that
 the to results are the same. 100  means that the strings are completely
 identical. 99 means that the strings match after all non-latin characters
-have been transliterated. Values in between 98 and 1 usually mean that the 
-given strings match. 0 means that the used alogorithm couldn't match the two 
+have been transliterated. Values in between 98 and 1 usually mean that the
+given strings match. 0 means that the used alogorithm couldn't match the two
 strings at all.
 C<compare> is a shortcut to the C<$obj-E<gt>_do_compare($CODE1,$CODE2)> method.
 
 =head2 Class Methods
 
-=head3 available_algorithms 
+=head3 available_algorithms
 
  my @available = Text::Phonetic->available_algorithms;
 
@@ -290,10 +289,10 @@ an array reference.
 =head2 _do_compare
 
  $RETURN_STRING = $obj->_do_compare($RESULT1,$RESULT2);
- 
-If your C<_do_encode> method doesn't return a single scalar value you also 
+
+If your C<_do_encode> method doesn't return a single scalar value you also
 might need to implement a comparison method. It takes two results as returned
-by C<_do_encode> and returns an integer value between 98 and 0 
+by C<_do_encode> and returns an integer value between 98 and 0
 (see L<"compare">).
 
 =head2 _predicates
@@ -312,25 +311,25 @@ Text::Phonetic uses L<Moo> to declare attributes.
 
  Text::Phonetic::_compare_list($LIST1_REF,$LIST2_REF);
 
-Compares the two arrays and returns true if at least one element is equal 
-(ignoring the position) in both lists.  
+Compares the two arrays and returns true if at least one element is equal
+(ignoring the position) in both lists.
 
 =head2 Example class
 
  package Text::Phonetic::MyAlgorithm;
  use Moo;
  extends qw(Text::Phonetic);
- 
+
  has someattribute => (
     is  => 'rw',
  );
- 
+
  sub _do_encode {
      my ($self,$string) = @_;
      # Do something
      return $phonetic_representation;
  }
- 
+
  __PACKAGE__->meta->make_immutable;
  no Moo;
  1;
@@ -342,10 +341,10 @@ L<Text::Phonetic::VideoGame> (Phonetic encoding for video game titles)
 
 =head1 SUPPORT
 
-Please report any bugs or feature requests to C<text-phonetic@rt.cpan.org>, or 
-through the web interface at 
-L<http://rt.cpan.org/Public/Bug/Report.html?Queue=Text::Phonetic>.  
-I will be notified, and then you'll automatically be notified of progress on 
+Please report any bugs or feature requests to C<text-phonetic@rt.cpan.org>, or
+through the web interface at
+L<http://rt.cpan.org/Public/Bug/Report.html?Queue=Text::Phonetic>.
+I will be notified, and then you'll automatically be notified of progress on
 your report as I make changes.
 
 =head1 AUTHOR
@@ -353,12 +352,12 @@ your report as I make changes.
     Maroš Kollár
     CPAN ID: MAROS
     maros [at] k-1.com
-    
+
     http://www.k-1.com
 
 =head1 COPYRIGHT
 
-Text::Phonetic is Copyright (c) 2006-2012 Maroš Kollár 
+Text::Phonetic is Copyright (c) 2006-2012 Maroš Kollár
 - L<http://www.k-1.com>
 
 =head1 LICENCE
