@@ -3,11 +3,9 @@ package Text::Phonetic::Real;
 # ============================================================================
 use utf8;
 
-use Moose;
+use Moo;
 extends qw(Text::Phonetic);
 
-__PACKAGE__->meta->make_immutable;
-
 our $VERSION = $Text::Phonetic::VERSION;
 
 sub _predicates {
@@ -19,4 +17,4 @@ sub _do_encode {
     return Text::SomePhoneticAlgorithm::phonetic($string);
 }
 
-1;
\ No newline at end of file
+1;
